Kytos SDN Platform
##################

|Experimental| |Tag| |Release| |License| |Build| |Coverage| |Quality|

`Kytos SDN Platform <https://kytos.io>`_ is the fastest way to deploy an SDN
Network. With this you can deploy a basic OpenFlow controller or your own
controller. Kytos was designed to be easy to install, use, develop and share
Network Apps (NApps). Kytos is incredibly powerful and easy, its modular design
makes Kytos a lightweight SDN Platform.

Kytos is conceived to ease SDN controllers development and deployment. It was
motivated by some gaps left by common SDN solutions. Moreover, it has strong
tights with a community view, so it is centered on the development of
applications by its users. Thus, our intention is not only to build a new SDN
solution, but also to build a community of developers around it, creating new
applications that benefit from the SDN paradigm.

The project was born in 2014 and has been under active development since
2016.

For more information about this project, please visit `Kytos project website
<https://kytos.io/>`_.


.. TAGs

.. |Experimental| image:: https://img.shields.io/badge/stability-experimental-orange.svg
   :target: https://github.com/kytos
.. |Tag| image:: https://img.shields.io/github/tag/kytos/kytos.svg
   :target: https://github.com/kytos/kytos/tags
.. |Release| image:: https://img.shields.io/github/release/kytos/kytos.svg
   :target: https://github.com/kytos/kytos/releases
.. |Tests| image:: https://travis-ci.org/kytos/kytos.svg?branch=master
   :target: https://travis-ci.org/kytos/kytos
.. |License| image:: https://img.shields.io/github/license/kytos/kytos.svg
   :target: https://github.com/kytos/kytos/blob/master/LICENSE
.. |Build| image:: https://scrutinizer-ci.com/g/kytos/kytos/badges/build.png?b=master
  :alt: Build status
  :target: https://scrutinizer-ci.com/g/kytos/kytos/?branch=master
.. |Coverage| image:: https://scrutinizer-ci.com/g/kytos/kytos/badges/coverage.png?b=master
  :alt: Code coverage
  :target: https://scrutinizer-ci.com/g/kytos/kytos/?branch=master
.. |Quality| image:: https://scrutinizer-ci.com/g/kytos/kytos/badges/quality-score.png?b=master
  :alt: Code-quality score
  :target: https://scrutinizer-ci.com/g/kytos/kytos/?branch=master
